@@ -14,7 +14,7 @@ our @EXPORT = qw(
     is_domain_label
 );
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 sub new {
     my $class = shift;
@@ -30,7 +30,9 @@ sub is_domain {
     return unless defined($value);
 
     my $length = length($value);
-    return unless ( $length > 0 && $length <= 255 );
+    return if $length < 0 || $length > 255;
+
+    my $trailing_dot = $value =~ s/\.\z// ? q{.} : q{};
 
     my @bits;
     foreach my $label ( split /\./, $value, -1 ) {
@@ -44,7 +46,7 @@ sub is_domain {
     unless ( defined $opt && $opt->{domain_allow_single_label} ) {
 
         #All domains have more then 1 label (neely.cx good, com not good)
-        return unless ( @bits >= 2 );
+        return if @bits < 2;
     }
 
     #If the option to enable domain_private_tld is enabled
@@ -69,7 +71,7 @@ sub is_domain {
     #Verify domain has a valid TLD
     return unless tld_exists($tld);
 
-    return join( '.', @bits );
+    return ( join( '.', @bits ) . $trailing_dot );
 }
 
 # -------------------------------------------------------------------------------
@@ -80,7 +82,7 @@ sub is_hostname {
     return unless defined($value);
 
     my $length = length($value);
-    return unless ( $length > 0 && $length <= 255 );
+    return if $length < 0 || $length > 255;
 
     #	return is_domain_label($value) unless $value =~ /\./;  #If just a simple hostname
 
@@ -151,13 +153,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Data::Validate::Domain - Domain and host name validation
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
@@ -254,8 +258,10 @@ domain.
 A dotted quad (such as 127.0.0.1) is not considered a domain and will return false.
 See L<Data::Validate::IP> for IP Validation.
 
-This sub does not consider a value ending a period (i.e. "domain.com.") to be
-a valid domain.
+Per RFC 1035, this sub does accept a value ending in a single period
+(i.e. "domain.com.") to be a valid domain. This is called an absolute domain
+name, and should be properly resolved by any DNS tool (tested with C<dig>,
+C<ssh>, and L<Net::DNS>).
 
 =over 4
 
@@ -335,6 +341,13 @@ Thanks to Richard Sonnen <F<sonnen@richardsonnen.com>> for writing the Data::Val
 
 Thanks to Len Reed <F<lreed@levanta.com>> for helping develop the options mechanism for Data::Validate modules.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|http://rt.cpan.org/Public/Dist/Display.html?Name=Data-Validate-Domain>
+(or L<bug-data-validate-domain@rt.cpan.org|mailto:bug-data-validate-domain@rt.cpan.org>).
+
+I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+
 =head1 AUTHORS
 
 =over 4
@@ -355,9 +368,9 @@ Dave Rolsky <autarch@urth.org>
 
 David Steinbrunner <dsteinbrunner@pobox.com>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
-This software is copyright (c) 2015 by Neil Neely.
+This software is copyright (c) 2016 by Neil Neely.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
